pub enum LogOutputDest {
Stderr,
Stdout,
Path(PathBuf),
}Variants
Stderr
Log to standard error
Stdout
Log to standard output
Path(PathBuf)
If a path with .log extension is provided, log to that file.
If a directory path is provided, log with file rotation enabled in that directory.
If the directory does not exist, it will be created.
Implementations
Sourceimpl LogOutputDest
impl LogOutputDest
pub fn parse_from_str(val: &str) -> Result<Self, Error>